@@ -1,3 +1,6 @@
+from os import system
+system("pip install getkey;pip install AnsiPrint;")
+
 from getkey import getkey
 from AnsiPrint import *
 
